@@ -30,7 +30,6 @@
 #include "speech.h"
 
 TextToSpeechSystem::TextToSpeechSystem() {
-   ttsCommand = "";
    stdIn = true;
    useKttsd = true;
    codec = Speech::Local; // local encoding;
@@ -44,15 +43,15 @@ TextToSpeechSystem::~TextToSpeechSystem() {
 bool kttsdSay (const QString &text, const QString &language) {
    // TODO: Would be better to save off this QDBusInterface pointer and
    // set defaults only once.
-   org::kde::KSpeech kspeech("org.kde.KSpeech", "/KSpeech", QDBusConnection::sessionBus());
-   kspeech.setApplicationName("KMouth");
+   org::kde::KSpeech kspeech(QLatin1String( "org.kde.KSpeech" ), QLatin1String( "/KSpeech" ), QDBusConnection::sessionBus());
+   kspeech.setApplicationName(QLatin1String( "KMouth" ));
    kspeech.setDefaultTalker(language);
 
    // FIXME: language is incorrect.
    kDebug() << "kttsdSay: language = " << language;
    kspeech.setDefaultPriority(KSpeech::jpWarning);
    QDBusReply<int> val = kspeech.say(text, 0);
-   
+
    return (val>0);
 }
 
@@ -78,16 +77,16 @@ void TextToSpeechSystem::readOptions (KConfig *config, const QString &langGroup)
   useKttsd = cg.readEntry("useKttsd", true);
 
   QString codecString = cg.readEntry("Codec", "Local");
-  if (codecString == "Local")
+  if (codecString == QLatin1String( "Local" ))
      codec = Speech::Local;
-  else if (codecString == "Latin1")
+  else if (codecString == QLatin1String( "Latin1" ))
      codec = Speech::Latin1;
-  else if (codecString == "Unicode")
+  else if (codecString == QLatin1String( "Unicode" ))
      codec = Speech::Unicode;
   else {
      codec = Speech::Local;
      for (int i = 0; i < codecList->count(); i++ )
-        if (codecString == codecList->at(i)->name())
+        if (codecString == QLatin1String( codecList->at(i)->name() ))
            codec = Speech::UseCodec + i;
   }
 }
@@ -104,7 +103,7 @@ void TextToSpeechSystem::saveOptions (KConfig *config, const QString &langGroup)
   else if (codec == Speech::Unicode)
      cg.writeEntry("Codec", "Unicode");
   else {
-     QString codeName = codecList->at (codec-Speech::UseCodec)->name();
+     QString codeName = QLatin1String( codecList->at (codec-Speech::UseCodec)->name() );
      cg.writeEntry("Codec", codeName);
   }
 }
